@@ -100,6 +100,42 @@ HONGKONG_MACAO_AND_TAIWAN 港澳台居民居住证(格式同居民身份证)
         
 
 
+class ApproverRestriction(AbstractModel):
+    """指定签署人限制项
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Name: 指定签署人名字
+        :type Name: str
+        :param Mobile: 指定签署人手机号
+        :type Mobile: str
+        :param IdCardType: 指定签署人证件类型
+        :type IdCardType: str
+        :param IdCardNumber: 指定签署人证件号码
+        :type IdCardNumber: str
+        """
+        self.Name = None
+        self.Mobile = None
+        self.IdCardType = None
+        self.IdCardNumber = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Mobile = params.get("Mobile")
+        self.IdCardType = params.get("IdCardType")
+        self.IdCardNumber = params.get("IdCardNumber")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Caller(AbstractModel):
     """此结构体 (Caller) 用于描述调用方属性。
 
@@ -277,16 +313,22 @@ class Component(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ComponentType: 如果是 Component 控件类型，则可选类型为：
-TEXT - 单行文本
-MULTI_LINE_TEXT - 多行文本
-CHECK_BOX - 勾选框
-ATTACHMENT - 附件
-SELECTOR - 选择器
-如果是 SignComponent 控件类型，则可选类型为：
-SIGN_SEAL - 签署印章控件，静默签署时需要传入印章id作为ComponentValue
-SIGN_DATE - 签署日期控件
-SIGN_SIGNATURE - 手写签名控件，静默签署时不能使用
+        :param ComponentType: 如果是Component控件类型，则可选的字段为：
+TEXT - 普通文本控件；
+MULTI_LINE_TEXT - 多行文本控件；
+CHECK_BOX - 勾选框控件；
+FILL_IMAGE - 图片控件；
+DYNAMIC_TABLE - 动态表格控件；
+ATTACHMENT - 附件控件；
+SELECTOR - 选择器控件；
+
+如果是SignComponent控件类型，则可选的字段为
+SIGN_SEAL - 签署印章控件；
+SIGN_DATE - 签署日期控件；
+SIGN_SIGNATURE - 用户签名控件；
+SIGN_PERSONAL_SEAL - 个人签署印章控件（使用文件发起暂不支持此类型）；
+
+表单域的控件不能作为印章和签名控件
         :type ComponentType: str
         :param ComponentWidth: 参数控件宽度，单位pt
         :type ComponentWidth: float
@@ -322,8 +364,9 @@ ESIGN -- 个人印章类型
 TEXT - 文本内容
 MULTI_LINE_TEXT - 文本内容
 CHECK_BOX - true/false
-ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
+FILL_IMAGE、ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
 SELECTOR - 选项值
+DYNAMIC_TABLE - 传入json格式的表格内容，具体见数据结构FlowInfo：https://cloud.tencent.com/document/api/1420/61525#FlowInfo
         :type ComponentValue: str
         :param IsFormType: 是否是表单域类型，默认不存在
         :type IsFormType: bool
@@ -386,6 +429,136 @@ KEYWORD 关键字，使用ComponentId指定关键字
         
 
 
+class CreateBatchCancelFlowUrlRequest(AbstractModel):
+    """CreateBatchCancelFlowUrl请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Operator: 调用方用户信息，userId 必填
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param FlowIds: 需要执行撤回的签署流程id数组，最多100个
+        :type FlowIds: list of str
+        """
+        self.Operator = None
+        self.FlowIds = None
+
+
+    def _deserialize(self, params):
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        self.FlowIds = params.get("FlowIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateBatchCancelFlowUrlResponse(AbstractModel):
+    """CreateBatchCancelFlowUrl返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param BatchCancelFlowUrl: 批量撤回签署流程链接
+        :type BatchCancelFlowUrl: str
+        :param FailMessages: 签署流程撤回失败信息
+        :type FailMessages: list of str
+        :param UrlExpireOn: 签署连接过期时间字符串：年月日-时分秒
+        :type UrlExpireOn: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.BatchCancelFlowUrl = None
+        self.FailMessages = None
+        self.UrlExpireOn = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.BatchCancelFlowUrl = params.get("BatchCancelFlowUrl")
+        self.FailMessages = params.get("FailMessages")
+        self.UrlExpireOn = params.get("UrlExpireOn")
+        self.RequestId = params.get("RequestId")
+
+
+class CreateConvertTaskApiRequest(AbstractModel):
+    """CreateConvertTaskApi请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ResourceId: 资源Id
+        :type ResourceId: str
+        :param ResourceType: 资源类型 取值范围doc,docx,html之一
+        :type ResourceType: str
+        :param ResourceName: 资源名称
+        :type ResourceName: str
+        :param Organization: 无
+        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
+        :param Operator: 无
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param Agent: 无
+        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        """
+        self.ResourceId = None
+        self.ResourceType = None
+        self.ResourceName = None
+        self.Organization = None
+        self.Operator = None
+        self.Agent = None
+
+
+    def _deserialize(self, params):
+        self.ResourceId = params.get("ResourceId")
+        self.ResourceType = params.get("ResourceType")
+        self.ResourceName = params.get("ResourceName")
+        if params.get("Organization") is not None:
+            self.Organization = OrganizationInfo()
+            self.Organization._deserialize(params.get("Organization"))
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateConvertTaskApiResponse(AbstractModel):
+    """CreateConvertTaskApi返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: 转换任务Id
+        :type TaskId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TaskId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateDocumentRequest(AbstractModel):
     """CreateDocument请求参数结构体
 
@@ -729,6 +902,8 @@ class CreateMultiFlowSignQRCodeRequest(AbstractModel):
         :type FlowEffectiveDay: int
         :param QrEffectiveDay: 二维码有效天数 默认7天 最高设置不超过90天
         :type QrEffectiveDay: int
+        :param ApproverRestrictions: 限制二维码用户条件
+        :type ApproverRestrictions: :class:`tencentcloud.ess.v20201111.models.ApproverRestriction`
         """
         self.TemplateId = None
         self.FlowName = None
@@ -738,6 +913,7 @@ class CreateMultiFlowSignQRCodeRequest(AbstractModel):
         self.MaxFlowNum = None
         self.FlowEffectiveDay = None
         self.QrEffectiveDay = None
+        self.ApproverRestrictions = None
 
 
     def _deserialize(self, params):
@@ -753,6 +929,9 @@ class CreateMultiFlowSignQRCodeRequest(AbstractModel):
         self.MaxFlowNum = params.get("MaxFlowNum")
         self.FlowEffectiveDay = params.get("FlowEffectiveDay")
         self.QrEffectiveDay = params.get("QrEffectiveDay")
+        if params.get("ApproverRestrictions") is not None:
+            self.ApproverRestrictions = ApproverRestriction()
+            self.ApproverRestrictions._deserialize(params.get("ApproverRestrictions"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -771,10 +950,13 @@ class CreateMultiFlowSignQRCodeResponse(AbstractModel):
         r"""
         :param QrCode: 签署二维码对象
         :type QrCode: :class:`tencentcloud.ess.v20201111.models.SignQrCode`
+        :param SignUrls: 签署链接对象
+        :type SignUrls: :class:`tencentcloud.ess.v20201111.models.SignUrl`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.QrCode = None
+        self.SignUrls = None
         self.RequestId = None
 
 
@@ -782,6 +964,9 @@ class CreateMultiFlowSignQRCodeResponse(AbstractModel):
         if params.get("QrCode") is not None:
             self.QrCode = SignQrCode()
             self.QrCode._deserialize(params.get("QrCode"))
+        if params.get("SignUrls") is not None:
+            self.SignUrls = SignUrl()
+            self.SignUrls._deserialize(params.get("SignUrls"))
         self.RequestId = params.get("RequestId")
 
 
@@ -1276,12 +1461,17 @@ class FlowBrief(AbstractModel):
         :param FlowType: 流程的类型
         :type FlowType: str
         :param FlowStatus: 流程状态
-- `1` 未签署
+- `0`  还没有发起
+- `1`  未签署
 - `2`  部分签署
 - `3`  已退回
 - `4`  完成签署
 - `5`  已过期
 - `6`  已取消
+- `7`  还没有预发起
+- `8`  等待填写
+- `9`  部分填写
+- `10`  拒填
 注意：此字段可能返回 null，表示取不到有效值。
         :type FlowStatus: int
         :param CreatedOn: 流程创建的时间戳
@@ -1402,12 +1592,13 @@ class FormField(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ComponentValue: 控件填充value，ComponentType和传入值类型对应关系：
+        :param ComponentValue: 控件填充vaule，ComponentType和传入值类型对应关系：
 TEXT - 文本内容
 MULTI_LINE_TEXT - 文本内容
 CHECK_BOX - true/false
-ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
-SELECTOR - 模板中配置的选项值
+FILL_IMAGE、ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
+SELECTOR - 选项值
+DYNAMIC_TABLE - 传入json格式的表格内容，具体见数据结构FlowInfo：https://cloud.tencent.com/document/api/1420/61525#FlowInfo
         :type ComponentValue: str
         :param ComponentId: 控件id，和ComponentName选择一项传入即可
         :type ComponentId: str
@@ -1432,6 +1623,121 @@ SELECTOR - 模板中配置的选项值
         
 
 
+class GetTaskResultApiRequest(AbstractModel):
+    """GetTaskResultApi请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: 任务Id
+        :type TaskId: str
+        :param Organization: 企业信息
+        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
+        :param Operator: 操作人信息
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param Agent: 渠道信息
+        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        """
+        self.TaskId = None
+        self.Organization = None
+        self.Operator = None
+        self.Agent = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        if params.get("Organization") is not None:
+            self.Organization = OrganizationInfo()
+            self.Organization._deserialize(params.get("Organization"))
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GetTaskResultApiResponse(AbstractModel):
+    """GetTaskResultApi返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: 任务Id
+        :type TaskId: str
+        :param TaskStatus: 任务状态
+        :type TaskStatus: int
+        :param TaskMessage: 状态描述
+        :type TaskMessage: str
+        :param ResourceId: 资源Id
+        :type ResourceId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TaskId = None
+        self.TaskStatus = None
+        self.TaskMessage = None
+        self.ResourceId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.TaskStatus = params.get("TaskStatus")
+        self.TaskMessage = params.get("TaskMessage")
+        self.ResourceId = params.get("ResourceId")
+        self.RequestId = params.get("RequestId")
+
+
+class OrganizationInfo(AbstractModel):
+    """机构信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param OrganizationId: 机构在平台的编号
+        :type OrganizationId: str
+        :param Channel: 用户渠道
+        :type Channel: str
+        :param OrganizationOpenId: 用户在渠道的机构编号
+        :type OrganizationOpenId: str
+        :param ClientIp: 用户真实的IP
+        :type ClientIp: str
+        :param ProxyIp: 机构的代理IP
+        :type ProxyIp: str
+        """
+        self.OrganizationId = None
+        self.Channel = None
+        self.OrganizationOpenId = None
+        self.ClientIp = None
+        self.ProxyIp = None
+
+
+    def _deserialize(self, params):
+        self.OrganizationId = params.get("OrganizationId")
+        self.Channel = params.get("Channel")
+        self.OrganizationOpenId = params.get("OrganizationOpenId")
+        self.ClientIp = params.get("ClientIp")
+        self.ProxyIp = params.get("ProxyIp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Recipient(AbstractModel):
     """签署参与者信息
 
@@ -1536,6 +1842,38 @@ class SignQrCode(AbstractModel):
         
 
 
+class SignUrl(AbstractModel):
+    """一码多扫签署二维码签署信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param AppSignUrl: 小程序签署链接
+        :type AppSignUrl: str
+        :param EffectiveTime: 签署链接有效时间
+        :type EffectiveTime: str
+        :param HttpSignUrl: 移动端签署链接
+        :type HttpSignUrl: str
+        """
+        self.AppSignUrl = None
+        self.EffectiveTime = None
+        self.HttpSignUrl = None
+
+
+    def _deserialize(self, params):
+        self.AppSignUrl = params.get("AppSignUrl")
+        self.EffectiveTime = params.get("EffectiveTime")
+        self.HttpSignUrl = params.get("HttpSignUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class StartFlowRequest(AbstractModel):
     """StartFlow请求参数结构体
 
